<?php

/* ************************************************************************************** 
	Define Metabox Fields
************************************************************************************** */

$shortname = 'swm';

/* General Options */

$meta_box_page = array(	
	'id' => 'swm-meta-box-page',
	'title' =>  __('Page Title Icon and Tagline', 'swmtranslate'),	
	'context' => 'normal',
	'page' => 'page',
	'priority' => 'high',
	'fields' => array(
		array(
			'name' => __('Upload Title page Icon', 'swmtranslate'),
			'desc' => '',
			'id' => $shortname.'_header_title_icon',
			'type' => 'text',
			'std' => ''
		),
		array(
			'name' => '',
			'desc' => __('Display page related icon in black header before title text', 'swmtranslate'),
			'id' => $shortname.'_upload_title_icon_button',
			'type' => 'button',
			'std' => 'Browse'
		),
		array(
			'name' => __('Page Tagline Text', 'swmtranslate'),
			'desc' => __('Add page tagline text in black header below title text', 'swmtranslate'),
			'id' => $shortname.'_sub_title_text',
			'type' => 'textarea',
			'std' => ''
		)
	)	
);

/* Exclude Categories */

$meta_box_exclude_portfolio_category = array(
	'id' => $shortname.'_exclude_portfolio_category',
	'title' =>  __('Portfolio Page Options', 'swmtranslate'),
	'page' => 'page',
	'context' => 'normal',
	'priority' => 'high',

	'fields' => array(
		array(
			'name' => __('<strong>Exclude Portfolio Categories</strong>', 'swmtranslate'),
			'desc' => __('Checked categories will be excluded from page display.', 'swmtranslate'),		
			'id' => $shortname.'_exclude_portfolio_categories',
			'type' => 'taxonomy',					
			'options' => array(
				'taxonomy' => 'portfolio_category',			
				'type' => 'checkbox_list',					
				'args' => array()					
			)		
		)
	)
);


/* ************************************************************************************** 
	Add Metabox
************************************************************************************** */
 
add_action('admin_menu', 'swm_add_meta_box_common');
 
function swm_add_meta_box_common() {
	global $meta_box_page, $meta_box_exclude_portfolio_category;	
	
	add_meta_box($meta_box_page['id'], $meta_box_page['title'], 'swm_display_meta_box_page', $meta_box_page['page'], $meta_box_page['context'], $meta_box_page['priority']);	
	add_meta_box($meta_box_exclude_portfolio_category['id'], $meta_box_exclude_portfolio_category['title'], 'swm_meta_box_exclude_portfolio_category', $meta_box_exclude_portfolio_category['page'], $meta_box_exclude_portfolio_category['context'], $meta_box_exclude_portfolio_category['priority']);	
}

/* ************************************************************************************** 
	Display Metabox in Admin Post
************************************************************************************** */

/* General Options */
 
function swm_display_meta_box_page() {
	global $meta_box_page, $post;
	
	echo '<input type="hidden" name="swm_meta_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';
 
	echo '<div class="swm-meta-box-post-format">';
 
	foreach ($meta_box_page['fields'] as $field) {
		
		$meta = get_post_meta($post->ID, $field['id'], true);
		switch ($field['type']) {			
			
			case 'text':			
				echo '<p><label for="', $field['id'], '">', $field['name'], '</label></p>';			
				echo '<p><input style="float: left; width:50%;" type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '" /></p>';				
			break;			
					
			case 'button':
				echo '<input style="float: left; width:auto; margin-left:5px;" type="button" class="button" name="', $field['id'], '" id="', $field['id'], '"value="', $meta ? $meta : $field['std'], '" />';			
				echo '<div class="clear"></div>';
				echo '<small>'.$field['desc'].'</small>';		
				echo '<hr />';
			break;		
			
			case 'textarea':			
				echo '<p><label for="', $field['id'], '">', $field['name'], '</label></p>';
				echo '<p><textarea name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '" rows="8" cols="4" >', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '</textarea></p>';
				echo '<small>'.$field['desc'].'</small>';
			break;
		}
	} 
	echo '</div>';
}

/* Exclude Categories */
 
function swm_meta_box_exclude_portfolio_category() {
	global $meta_box_exclude_portfolio_category, $post;
	
	echo '<input type="hidden" name="swm_meta_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';
 
	echo '<div class="swm-meta-box-post-format">';
	
	
 
	foreach ($meta_box_exclude_portfolio_category['fields'] as $field) {		
		
		echo $field['name'];	
		
		$meta = get_post_meta($post->ID, $field['id'], true);
		$options = $field['options'];
		$terms = get_terms($options['taxonomy'], $options['args']);		
		
		if (!is_array($meta)) { $meta = (array) $meta; }
		
		foreach ($terms as $term) {
			echo "<p><input  class=\"checkbox-list\" type='checkbox' id='tax-$term->term_id' name='{$field['id']}[]' value='$term->term_id'" . checked(in_array($term->term_id, $meta), true, false) . " /> <label for='tax-$term->term_id'> $term->name";
			echo '</p>';
		}		
	} 
	
	echo '<small>'.$field['desc'].'</small>';
	
	echo '</div>';
}

/* ************************************************************************************** 
	Save Metabox Data
************************************************************************************** */

add_action('save_post', 'swm_save_data_all');
 
function swm_save_data_all($post_id) {
	global $meta_box_page,$meta_box_exclude_portfolio_category;
 
	// verify nonce
	if (!isset($_POST['swm_meta_box_nonce']) || !wp_verify_nonce($_POST['swm_meta_box_nonce'], basename(__FILE__))) {
		return $post_id;
	}
 
	// check autosave
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return $post_id;
	}
 
	// check permissions
	if ('page' == $_POST['post_type']) {
		if (!current_user_can('edit_page', $post_id)) {
			return $post_id;
		}
	} elseif (!current_user_can('edit_post', $post_id)) {
		return $post_id;
	} 
	
	/* General Options */
	foreach ($meta_box_page['fields'] as $field) {
		$old = get_post_meta($post_id, $field['id'], true);
		$new = $_POST[$field['id']];
 
		if ($new && $new != $old) {
			update_post_meta($post_id, $field['id'], $new);
		} elseif ('' == $new && $old) {
			delete_post_meta($post_id, $field['id'], $old);
		}
	}	
	
	/* Exclude Categories */	 
	foreach ($meta_box_exclude_portfolio_category['fields'] as $field) {
		$name = $field['id'];
		$type = $field['type'];
		$old = get_post_meta($post_id, $name, !$field['multiple']);
		$new = isset($_POST[$name]) ? $_POST[$name] : ($field['multiple'] ? array() : '');
		
		delete_post_meta($post_id, $name);
		if (empty($new)) return;

		if ($field['multiple']) {
			foreach ($new as $add_new) {
				add_post_meta($post_id, $name, $add_new, false);
			}
		} else {
				update_post_meta($post_id, $name, $new);
		}			
	}
	
}

/*-----------------------------------------------------------------------------------*/
/*	Queue Scripts
/*-----------------------------------------------------------------------------------*/
 

