<?php

/* ******************************************* 
	Define Metabox Fields
******************************************* */

$shortname = 'swm';

$meta_box_slider = array(	
	'id' => 'swm-meta-box-slider',
	'title' =>  __('Add Slider Details', 'swmtranslate'),
	'page' => 'slider',
	'context' => 'normal',
	'priority' => 'high',
	'fields' => array(		
		array(
			'name' => __('Slide Type', 'swmtranslate'),
			'desc' => __('Select image or video slide', 'swmtranslate'),
			'id' => $shortname.'_slider_type',
			'type' => 'select',
			'std' => '',			
			'options' => array(
				__('Image', 'swmtranslate'), 				
				__('Video', 'swmtranslate')),					
		),		
		array(
			'name' => __('Image / Video Width Size', 'swmtranslate'),
			'desc' => __('Select image or video slide size', 'swmtranslate'),
			'id' => $shortname.'_slide_size',
			'type' => 'select',
			'std' => '',			
			'options' => array(
				__('One Half Width', 'swmtranslate'), 				
				__('Full Width', 'swmtranslate')),					
		),
		array(
			'name' => __('Image / Video Alignment', 'swmtranslate'),
			'desc' => __('If slide size is one half then select alignment.', 'swmtranslate'),
			'id' => $shortname.'_slide_alignment',
			'type' => 'select',
			'std' => '',			
			'options' => array(
				__('Image/Video Left and Text Right', 'swmtranslate'), 				
				__('Image/Video Right and Text Left', 'swmtranslate')),					
		),
		array(
			'name' => __('Video URL', 'swmtranslate'),
			'desc' => __('If slide type is video then enter video embed url', 'swmtranslate'),
			'id' => $shortname.'_slider_video_url',
			'type' => 'text',
			'std' => ''
		),		
		array(
			'name' => __('Hyperlink URL (If Image Slide)', 'swmtranslate'),
			'desc' => __('If you want to clickable image slide then enter url of the page/post', 'swmtranslate'),
			'id' => $shortname.'_slider_image_link',
			'type' => 'text',
			'std' => ''
		)
	)	
);

/* ******************************************* 
	Add Metabox
******************************************* */
 
add_action('admin_menu', 'swm_add_meta_box_slider');
 
function swm_add_meta_box_slider() {
	global $meta_box_slider;	
	
	add_meta_box($meta_box_slider['id'], $meta_box_slider['title'], 'swm_display_meta_box_slider', $meta_box_slider['page'], $meta_box_slider['context'], $meta_box_slider['priority']);	
	
}

/* ******************************************* 
	Display Metabox in Admin Post
******************************************* */

function swm_display_meta_box_slider() {
	global $meta_box_slider, $post;
	
	echo '<input type="hidden" name="swm_meta_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';
 
	echo '<div class="swm-meta-box-post-format">';
 
	foreach ($meta_box_slider['fields'] as $field) {
		
		$options = $field['options'];
		$meta = get_post_meta($post->ID, $field['id'], true);
		
		switch ($field['type']) {			
			
			case 'text':			
				echo '<p><label for="', $field['id'], '">', $field['name'], '</label>';	
				echo '<small>'.$field['desc'].'</small>';
				echo '<input type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '" /></p>';				
				echo '<hr />';
				break;
			
			case 'textarea':			
				echo '<p><label for="', $field['id'], '">', $field['name'], '</label>';
				echo '<small>'.$field['desc'].'</small></p>';
				echo '<p><textarea name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '" rows="8" cols="4" >', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '</textarea></p>';	
				echo '<hr />';
				break;			
			
			case 'select':
			
				echo '<p><label class="swm-metabox-select-label" for="', $field['id'], '">', $field['name'], '<small>'. $field['desc'].'</small></label></p>';
			
				echo'<select class="swm-metabox-select" name="'.$field['id'].'">';
			
				foreach ($field['options'] as $option) {					
					echo'<option';
					if ($meta == $option ) { 
						echo ' selected="selected"'; 
					}
					echo'>'.$option.'</option>';				
				}				
				echo'</select>';
				echo '<div class="clear"></div>';
				echo '<hr />';
				break;
		}
	} 
	echo '</div>';
}

/* ******************************************* 
	Save Metabox Data
******************************************* */

add_action('save_post', 'swm_save_data_slider');
 
function swm_save_data_slider($post_id) {
	global $meta_box_slider;
 
	// verify nonce
	if (!isset($_POST['swm_meta_box_nonce']) || !wp_verify_nonce($_POST['swm_meta_box_nonce'], basename(__FILE__))) {
		return $post_id;
	}
 
	// check autosave
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return $post_id;
	}
 
	// check permissions
	if ('page' == $_POST['post_type']) {
		if (!current_user_can('edit_page', $post_id)) {
			return $post_id;
		}
	} elseif (!current_user_can('edit_post', $post_id)) {
		return $post_id;
	} 	
	
	foreach ($meta_box_slider['fields'] as $field) {
		$old = get_post_meta($post_id, $field['id'], true);
		$new = $_POST[$field['id']];
 
		if ($new && $new != $old) {
			update_post_meta($post_id, $field['id'], stripslashes(htmlspecialchars($new)));
		} elseif ('' == $new && $old) {
			delete_post_meta($post_id, $field['id'], $old);
		}
	}
	
}