<?php

/* ******************************************* 
	Define Metabox Fields
******************************************* */

$shortname = 'swm';

$meta_box_testimonials = array(	
	'id' => 'swm-meta-box-testimonials',
	'title' =>  __('Testimonial Options', 'swmtranslate'),
	'page' => 'testimonials',
	'context' => 'normal',
	'priority' => 'high',
	'fields' => array(		
		array(
				'name' => __('Client Details (optional)', 'swmtranslate'),
				'desc' => __('Client designation, city or country name etc. ', 'swmtranslate'),
				'id' => $shortname.'_client_details',
				'type' => 'text',
				'std' => ''
		),
		array(
				'name' => __('Website Title (optional)', 'swmtranslate'),
				'desc' => __('Client website or company name', 'swmtranslate'),
				'id' => $shortname.'_website_title',
				'type' => 'text',
				'std' => ''
		),
		array(
				'name' => __('Website URL (optional)', 'swmtranslate'),
				'desc' => __('Client website url', 'swmtranslate'),
				'id' => $shortname.'_website_url',
				'type' => 'text',
				'std' => ''
		)	
	)	
);

/* ******************************************* 
	Add Metabox
******************************************* */
 
add_action('admin_menu', 'swm_add_meta_box_testimonials');
 
function swm_add_meta_box_testimonials() {
	global $meta_box_testimonials;	
	
	add_meta_box($meta_box_testimonials['id'], $meta_box_testimonials['title'], 'swm_display_meta_box_testimonials', $meta_box_testimonials['page'], $meta_box_testimonials['context'], $meta_box_testimonials['priority']);	
	
}

/* ******************************************* 
	Display Metabox in Admin Post
******************************************* */

function swm_display_meta_box_testimonials() {
	global $meta_box_testimonials, $post;
	
	echo '<input type="hidden" name="swm_meta_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';
 
	echo '<div class="swm-meta-box-post-format">';
 
	foreach ($meta_box_testimonials['fields'] as $field) {
		
		$meta = get_post_meta($post->ID, $field['id'], true);
		switch ($field['type']) {			
			
			case 'text':			
			echo '<p><label for="', $field['id'], '">', $field['name'], '</label>';	
			echo '<small>'.$field['desc'].'</small>';
			echo '<input type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '" /></p>';
			
			echo '<hr />';
			break;
			
			case 'textarea':			
				echo '<p><label for="', $field['id'], '">', $field['name'], '</label></p>';
				echo '<p><textarea name="', $field['id'], '" id="', $field['id'], '" value="', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '" rows="8" cols="4" >', $meta ? $meta : stripslashes(htmlspecialchars(( $field['std']), ENT_QUOTES)), '</textarea></p>';			
			break;
		}
	} 
	echo '</div>';
}

/* ******************************************* 
	Save Metabox Data
******************************************* */

add_action('save_post', 'swm_save_data_testimonials');
 
function swm_save_data_testimonials($post_id) {
	global $meta_box_testimonials;
 
	// verify nonce
	if (!isset($_POST['swm_meta_box_nonce']) || !wp_verify_nonce($_POST['swm_meta_box_nonce'], basename(__FILE__))) {
		return $post_id;
	}
 
	// check autosave
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		return $post_id;
	}
 
	// check permissions
	if ('page' == $_POST['post_type']) {
		if (!current_user_can('edit_page', $post_id)) {
			return $post_id;
		}
	} elseif (!current_user_can('edit_post', $post_id)) {
		return $post_id;
	} 	
	
	foreach ($meta_box_testimonials['fields'] as $field) {
		$old = get_post_meta($post_id, $field['id'], true);
		$new = $_POST[$field['id']];
 
		if ($new && $new != $old) {
			update_post_meta($post_id, $field['id'], stripslashes(htmlspecialchars($new)));
		} elseif ('' == $new && $old) {
			delete_post_meta($post_id, $field['id'], $old);
		}
	}
	
}