<?php
/*-----------------------------------------------------------------------------------*/
/*	Theme Setup
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'photographer_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since photographer 1.0
 */
function photographer_setup() {

	// Make theme available for translation
	load_theme_textdomain( 'organicthemes', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// Add title tag support
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails
	add_theme_support( 'post-thumbnails' );
	
	add_image_size( 'photographer-featured-large', 1800, 1800 ); // Featured Large
	add_image_size( 'photographer-featured-medium', 1200, 1200 ); // Featured Medium
	add_image_size( 'photographer-featured-small', 640, 640 ); // Featured Small

	// Register Menus
	register_nav_menus( array(
		'header-menu' => __( 'Header Menu', 'organicthemes' ),
		'social-menu' => __( 'Social Menu', 'organicthemes' ),
	));
	
	// Add HTML5 support for search, comments, galleries and captions
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'caption',
	) );
	
	// Custom Header
	$defaults = array(
		'width'                 => 1800,
		'height'                => 600,
		'default-image'			=> '',
		'flex-height'           => true,
		'flex-width'            => true,
		'default-text-color'    => '333333',
		'header-text'           => false,
		'uploads'               => true,
	);
	add_theme_support( 'custom-header', $defaults );
	
	// Custom Background
	$defaults = array(
		'default-color'          => 'f9f9f9',
	);
	add_theme_support( 'custom-background', $defaults );
}
endif; // organic_setup
add_action( 'after_setup_theme', 'photographer_setup' );

/*-----------------------------------------------------------------------------------------------------//	
	Category ID to Name		       	     	 
-------------------------------------------------------------------------------------------------------*/

function photographer_cat_id_to_name($id) {
	foreach((array)(get_categories()) as $category) {
    	if ($id == $category->cat_ID) { return $category->cat_name; break; }
	}
}

/*-----------------------------------------------------------------------------------------------------//	
	Register Scripts		       	     	 
-------------------------------------------------------------------------------------------------------*/

if( !function_exists('photographer_enqueue_scripts') ) {
	function photographer_enqueue_scripts() {
	    
	    // Enqueue Styles
    	wp_enqueue_style( 'photographer-style', get_stylesheet_uri() );
    	wp_enqueue_style( 'photographer-style-mobile', get_template_directory_uri() . '/css/style-mobile.css', array( 'photographer-style' ), '1.0' );
    	
    	// Resgister Scripts
    	wp_register_script( 'photographer-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '20130729' );
    	wp_register_script( 'photographer-hover', get_template_directory_uri() . '/js/hoverIntent.js', array( 'jquery' ), '20130729' );
    	wp_register_script( 'photographer-superfish', get_template_directory_uri() . '/js/superfish.js', array( 'jquery', 'photographer-hover' ), '20130729' );
    
    	// Enqueue Scripts
    	wp_enqueue_script( 'photographer-html5shiv', get_template_directory_uri() . '/js/html5shiv.js' );
    	wp_enqueue_script( 'photographer-custom', get_template_directory_uri() . '/js/jquery.custom.js', array( 'jquery', 'photographer-superfish', 'photographer-fitvids', 'masonry' ), '20130729', true );
    	wp_enqueue_script( 'photographer-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20130729', true );
    	
    	// IE Conditional Scripts
    	global $wp_scripts;
    	$wp_scripts->add_data( 'photographer-html5shiv', 'conditional', 'lt IE 9' );
    	
    	// Load Flexslider on front page and slideshow page template
    	if ( is_home() || is_front_page() || is_singular('jetpack-portfolio') || is_page_template('template-slideshow.php') || is_page_template('template-home.php') ) {
    		wp_enqueue_script( 'photographer-flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array( 'jquery' ), '20130729' );
    	}
    
    	// Load single scripts only on single pages
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        	wp_enqueue_script( 'comment-reply' );
        }
	}
	add_action('wp_enqueue_scripts', 'photographer_enqueue_scripts');
}

/*-----------------------------------------------------------------------------------------------------//	
	WooCommerce Integration			       	     	 
-------------------------------------------------------------------------------------------------------*/

// Remove declare support message
add_theme_support('woocommerce');

// Remove WC sidebar
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );

// WooCommerce content wrappers
function photographer_prepare_woocommerce_wrappers(){
    remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
    remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
    add_action( 'woocommerce_before_main_content', 'photographer_open_woocommerce_content_wrappers', 10 );
    add_action( 'woocommerce_after_main_content', 'photographer_close_woocommerce_content_wrappers', 10 );
}
add_action( 'wp_head', 'photographer_prepare_woocommerce_wrappers' );

function photographer_open_woocommerce_content_wrappers() {
	?>  
	<div class="container">
		<div class="row">
			<div class="eight columns">
 				<div class="post-area">
    <?php
}

function photographer_close_woocommerce_content_wrappers() {
	?>
	    		</div> <!-- /post-area -->
	    	</div> <!-- /columns -->
	 
	        <div class="four columns">
	        	<?php get_sidebar(); ?>
	        </div>
	        
	 	</div> <!-- /row -->
    </div> <!-- /container --> 
    <?php
}

// Add the WC sidebar in the right place
add_action( 'woo_main_after', 'woocommerce_get_sidebar', 10 );

// WooCommerce thumbnail image sizes
global $pagenow;
if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) add_action('init', 'woo_install_theme', 1);
function woo_install_theme() {
 
update_option( 'woocommerce_thumbnail_image_width', '192' );
update_option( 'woocommerce_thumbnail_image_height', '192' );
update_option( 'woocommerce_single_image_width', '600' );
update_option( 'woocommerce_single_image_height', '600' );
update_option( 'woocommerce_catalog_image_width', '140' );
update_option( 'woocommerce_catalog_image_height', '140' );
}

// WooCommerce default product columns
add_filter('loop_shop_columns', 'loop_columns');
	if (!function_exists('loop_columns')) {
		function loop_columns() {
	return 4; // 4 products per row
	}
}

// WooCommerce remove related products
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);

/*-----------------------------------------------------------------------------------------------------//	
	Register Sidebars		       	     	 
-------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'photographer_widgets_init' ) ) { 
	function photographer_widgets_init() {
		register_sidebar(array(
			'name'=> __( "Default Sidebar", 'organicthemes' ),
			'id' => 'default-sidebar',
			'before_widget'=>'<div id="%1$s" class="widget %2$s">',
			'after_widget'=>'</div>',
			'before_title'=>'<h6 class="title">',
			'after_title'=>'</h6>'
		));
		register_sidebar(array(
			'name'=> __( "Home Sidebar", 'organicthemes' ),
			'id' => 'home-sidebar',
			'before_widget'=>'<div id="%1$s" class="widget %2$s">',
			'after_widget'=>'</div>',
			'before_title'=>'<h6 class="title">',
			'after_title'=>'</h6>'
		));
		register_sidebar(array(
			'name'=> __( "Blog Sidebar", 'organicthemes' ),
			'id' => 'blog-sidebar',
			'before_widget'=>'<div id="%1$s" class="widget %2$s">',
			'after_widget'=>'</div>',
			'before_title'=>'<h6 class="title">',
			'after_title'=>'</h6>'
		));
		register_sidebar(array(
			'name'=> __( "Archive Sidebar", 'organicthemes' ),
			'id' => 'archive-sidebar',
			'before_widget'=>'<div id="%1$s" class="widget %2$s">',
			'after_widget'=>'</div>',
			'before_title'=>'<h6 class="title">',
			'after_title'=>'</h6>'
		));
		register_sidebar(array(
			'name'=> __( "Left Sidebar", 'organicthemes' ),
			'id' => 'left-sidebar',
			'before_widget'=>'<div id="%1$s" class="widget %2$s">',
			'after_widget'=>'</div>',
			'before_title'=>'<h6 class="title">',
			'after_title'=>'</h6>'
		));
	}
	add_action( 'widgets_init', 'photographer_widgets_init' );
}
	
/*----------------------------------------------------------------------------------------------------//
/*	Content Width
/*----------------------------------------------------------------------------------------------------*/

if ( ! isset( $content_width ) )
	$content_width = 640;

/**
 * Adjust content_width value based on the presence of widgets
 */
function photographer_content_width() {
	if ( ! is_active_sidebar( 'default-sidebar' ) || is_active_sidebar( 'home-sidebar' ) ) {
		global $content_width;
		$content_width = 960;
	}
}
add_action( 'template_redirect', 'photographer_content_width' );
	
/*-----------------------------------------------------------------------------------------------------//	
	Comments Function		       	     	 
-------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'photographer_comment' ) ) :
function photographer_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'organicthemes' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'organicthemes' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 72;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 48;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s <br/> %2$s <br/>', 'organicthemes' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s', 'organicthemes' ), get_comment_date(), get_comment_time() )
							)
						);
					?>
				</div><!-- .comment-author .vcard -->
			</footer>

			<div class="comment-content">
				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'organicthemes' ); ?></em>
					<br />
				<?php endif; ?>
				<?php comment_text(); ?>
				<div class="reply">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'organicthemes' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div><!-- .reply -->
				<?php edit_comment_link( __( 'Edit', 'organicthemes' ), '<span class="edit-link">', '</span>' ); ?>
			</div>

		</article><!-- #comment-## -->

	<?php
	break;
	endswitch;
}
endif; // ends check for organicthemes_comment()

/*-----------------------------------------------------------------------------------*/
/*	Pagination Function
/*-----------------------------------------------------------------------------------*/

function photographer_get_pagination_links() {
	global $wp_query;
	$big = 999999999;
	echo paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => '?paged=%#%',
		'current' => max( 1, get_query_var('paged') ),
		'prev_text' => __('&laquo;', 'organicthemes'),
		'next_text' => __('&raquo;', 'organicthemes'),
		'total' => $wp_query->max_num_pages
	) );
}

/*-----------------------------------------------------------------------------------------------------//
	Add Stylesheet To Visual Editor
-------------------------------------------------------------------------------------------------------*/
	
add_action( 'widgets_init', 'photographer_add_editor_styles' );
/**
* Apply theme's stylesheet to the visual editor.
*
* @uses add_editor_style() Links a stylesheet to visual editor
* @uses get_stylesheet_uri() Returns URI of theme stylesheet
*/
function photographer_add_editor_styles() {
	add_editor_style( 'css/style-editor.css' );
}

/*-----------------------------------------------------------------------------------*/
/*	Custom Page Links
/*-----------------------------------------------------------------------------------*/

function photographer_wp_link_pages_args_prevnext_add($args) {
    global $page, $numpages, $more, $pagenow;

    if (!$args['next_or_number'] == 'next_and_number') 
        return $args; 

    $args['next_or_number'] = 'number'; // Keep numbering for the main part
    if (!$more)
        return $args;

    if($page-1) // There is a previous page
        $args['before'] .= _wp_link_page($page-1)
            . $args['link_before']. $args['previouspagelink'] . $args['link_after'] . '</a>';

    if ($page<$numpages) // There is a next page
        $args['after'] = _wp_link_page($page+1)
            . $args['link_before'] . $args['nextpagelink'] . $args['link_after'] . '</a>'
            . $args['after'];

    return $args;
}

add_filter('wp_link_pages_args', 'photographer_wp_link_pages_args_prevnext_add');

/*-----------------------------------------------------------------------------------------------------//	
	Featured Video Meta Box		       	     	 
-------------------------------------------------------------------------------------------------------*/

add_action("admin_init", "photographer_admin_init_featurevid");
add_action('save_post', 'photographer_save_featurevid');

function photographer_admin_init_featurevid(){
	add_meta_box("featurevid-meta", __("Featured Video Embed Code", 'organicthemes'), "photographer_meta_options_featurevid", "post", "normal", "high");
}

function photographer_meta_options_featurevid(){
	global $post;
	$custom = get_post_custom($post->ID);
	$featurevid = $custom["featurevid"][0];

	echo '<textarea name="featurevid" cols="60" rows="4" style="width:97.6%" />'.$featurevid.'</textarea>';
}

function photographer_save_featurevid($post_id){
	global $post;
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return $post_id;
    }
	if ( isset($_POST["featurevid"]) ) { 
		update_post_meta($post->ID, "featurevid", $_POST["featurevid"]); 
	}
}

/*-----------------------------------------------------------------------------------------------------//	
	Navigation Support		       	     	 
-------------------------------------------------------------------------------------------------------*/

// Display home link in custom menu
function photographer_home_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter('wp_page_menu_args', 'photographer_home_page_menu_args');

/*-----------------------------------------------------------------------------------------------------//	
	Strip inline width and height attributes from WP generated images		       	     	 
-------------------------------------------------------------------------------------------------------*/
 
function photographer_remove_thumbnail_dimensions( $html ) { 
	$html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html ); 
	return $html; 
	}
add_filter( 'post_thumbnail_html', 'photographer_remove_thumbnail_dimensions', 10 ); 
add_filter( 'image_send_to_editor', 'photographer_remove_thumbnail_dimensions', 10 );

/*-----------------------------------------------------------------------------------------------------//
	Filters wp_title to print a neat <title> tag based on what is being viewed.
-------------------------------------------------------------------------------------------------------*/

function photographer_wp_title( $title, $sep ) {
	global $page, $paged;

	if ( is_feed() )
		return $title;

	// Add the blog name
	$title .= get_bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title .= " $sep $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		$title .= " $sep " . sprintf( __( 'Page %s', 'organicthemes' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'photographer_wp_title', 10, 2 );

/*-----------------------------------------------------------------------------------------------------//
	Includes
-------------------------------------------------------------------------------------------------------*/

/*
 * Jetpack
 */
require_once( get_template_directory() . '/includes/jetpack.php' );

/*
 * Theme Updater
 */
require_once( get_template_directory() . '/includes/theme-updater.php' );

/*
 * Theme Customizer
 */
require_once ( get_template_directory() . '/includes/customizer.php' );

/*
 * Theme Typefaces
 */
require_once( get_template_directory() . '/includes/typefaces.php' );

/*
 * Theme Shortcodes
 */
include_once( get_template_directory() . '/organic-shortcodes/organic-shortcodes.php' );