<?php
/**
* Theme customizer with real-time update
*
* Very helpful: http://ottopress.com/2012/theme-customizer-part-deux-getting-rid-of-options-pages/
*
* @package Photographer
* @since Photographer 3.0
*/
function photographer_theme_customizer( $wp_customize ) {

	// Category Dropdown Control
	class Photographer_Category_Dropdown_Control extends WP_Customize_Control {
	public $type = 'dropdown-categories';

	public function render_content() {
		$dropdown = wp_dropdown_categories(
				array(
					'name'              => '_customize-dropdown-categories-' . $this->id,
					'echo'              => 0,
					'show_option_none'  => __( '&mdash; Select &mdash;', 'organicthemes' ),
					'option_none_value' => '0',
					'selected'          => $this->value(),
				)
			);

			// Hackily add in the data link parameter.
			$dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );

			printf( '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
				$this->label,
				$dropdown
			);
		}
	}
	
	function photographer_sanitize_categories( $input ) {
		$categories = get_terms( 'category', array('fields' => 'ids', 'get' => 'all') );
		
	   if ( in_array( $input, $categories ) ) {
	       return $input;
	   } else {
	   	return '';
	   }
	}
	
	function photographer_sanitize_pages( $input ) {
		$pages = get_all_page_ids();
	 
	    if ( in_array( $input, $pages ) ) {
	        return $input;
	    } else {
	    	return '';
	    }
	}
	
	function photographer_sanitize_transition_interval( $input ) {
	    $valid = array(
	        '2000' 		=> __( '2 Seconds', 'organicthemes' ),
	        '4000' 		=> __( '4 Seconds', 'organicthemes' ),
	        '6000' 		=> __( '6 Seconds', 'organicthemes' ),
	        '8000' 		=> __( '8 Seconds', 'organicthemes' ),
	        '10000' 	=> __( '10 Seconds', 'organicthemes' ),
	        '12000' 	=> __( '12 Seconds', 'organicthemes' ),
	        '20000' 	=> __( '20 Seconds', 'organicthemes' ),
	        '30000' 	=> __( '30 Seconds', 'organicthemes' ),
	        '60000' 	=> __( '1 Minute', 'organicthemes' ),
	        '999999999'	=> __( 'Hold Frame', 'organicthemes' ),
	    );
	 
	    if ( array_key_exists( $input, $valid ) ) {
	        return $input;
	    } else {
	        return '';
	    }
	}
	
	function photographer_sanitize_transition_style( $input ) {
	    $valid = array(
	        'fade' 		=> __( 'Fade', 'organicthemes' ),
	        'slide' 	=> __( 'Slide', 'organicthemes' ),
	    );
	 
	    if ( array_key_exists( $input, $valid ) ) {
	        return $input;
	    } else {
	        return '';
	    }
	}
	
	function photographer_sanitize_columns( $input ) {
	    $valid = array(
	        'one' 		=> __( 'One Column', 'organicthemes' ),
	        'two' 		=> __( 'Two Columns', 'organicthemes' ),
	        'three' 	=> __( 'Three Columns', 'organicthemes' ),
	        'four'	 	=> __( 'Four Columns', 'organicthemes' ),
	    );
	 
	    if ( array_key_exists( $input, $valid ) ) {
	        return $input;
	    } else {
	        return '';
	    }
	}
	
	function photographer_sanitize_checkbox( $input ) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}
	
	function photographer_sanitize_align( $input ) {
	    $valid = array(
	        'left' 		=> __( 'Left Align', 'organicthemes' ),
	        'center' 		=> __( 'Center Align', 'organicthemes' ),
	        'right' 	=> __( 'Right Align', 'organicthemes' ),
	    );
	 
	    if ( array_key_exists( $input, $valid ) ) {
	        return $input;
	    } else {
	        return '';
	    }
	}
	
	function photographer_sanitize_text( $input ) {
	    return wp_kses_post( force_balance_tags( $input ) );
	}

	// Set site name and description text to be previewed in real-time
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// Set site title color to be previewed in real-time
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
//-------------------------------------------------------------------------------------------------------------------//
// Site Title Section
//-------------------------------------------------------------------------------------------------------------------//	

	$wp_customize->add_section( 'title_tagline' , array(
		'title'       => __( 'Site Title, Tagline & Logo', 'organicthemes' ),
		'priority'    => 1,
	) );
	
		// Logo uploader
		$wp_customize->add_setting( 'photographer_logo', array(
			'default' 	=> get_template_directory_uri() . '/images/logo.png',
			'sanitize_callback' => 'esc_url_raw',
		) );
		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'photographer_logo', array(
			'label' 	=> __( 'Logo', 'organicthemes' ),
			'section' 	=> 'title_tagline',
			'settings'	=> 'photographer_logo',
			'priority'	=> 1,
		) ) );
		
		// Site Title Align
		$wp_customize->add_setting( 'title_align', array(
		    'default' => 'center',
		    'sanitize_callback' => 'photographer_sanitize_align',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'title_align', array(
		    'type' => 'radio',
		    'label' => __( 'Title & Logo Alignment', 'organicthemes' ),
		    'section' => 'title_tagline',
		    'choices' => array(
		        'left' 		=> __( 'Left Align', 'organicthemes' ),
		        'center' 	=> __( 'Center Align', 'organicthemes' ),
		        'right' 	=> __( 'Right Align', 'organicthemes' ),
		    ),
		    'priority' => 20,
		) ) );

//-------------------------------------------------------------------------------------------------------------------//
// Colors Section
//-------------------------------------------------------------------------------------------------------------------//
		
		// Link Color
		$wp_customize->add_setting( 'photographer_link_color', array(
		    'default' => '#000000',
		    'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'photographer_link_color', array(
		    'label' => 'Link Color',
		    'section' => 'colors',
		    'settings' => 'photographer_link_color',
		    'priority'    => 40,
		) ) );

		// Link Hover Color
		$wp_customize->add_setting( 'photographer_link_hover_color', array(
		    'default' => '#66CCCC',
		    'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'photographer_link_hover_color', array(
		    'label' => 'Link Hover Color',
		    'section' => 'colors',
		    'settings' => 'photographer_link_hover_color',
		    'priority'    => 50,
		) ) );
		
		// Heading Link Color
		$wp_customize->add_setting( 'photographer_heading_link_color', array(
		    'default' => '#000000',
		    'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'photographer_heading_link_color', array(
		    'label' => 'Heading Link Color',
		    'section' => 'colors',
		    'settings' => 'photographer_heading_link_color',
		    'priority'    => 60,
		) ) );
		
		// Heading Link Hover Color
		$wp_customize->add_setting( 'photographer_heading_link_hover_color', array(
		    'default' => '#66CCCC',
		    'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'photographer_heading_link_hover_color', array(
		    'label' => 'Heading Link Hover Color',
		    'section' => 'colors',
		    'settings' => 'photographer_heading_link_hover_color',
		    'priority'    => 70,
		) ) );
		
		// Highlight Color
		$wp_customize->add_setting( 'photographer_highlight_color', array(
		    'default' => '#66CCCC',
		    'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'photographer_highlight_color', array(
		    'label' => 'Highlight Color',
		    'section' => 'colors',
		    'settings' => 'photographer_highlight_color',
		    'priority'    => 80,
		) ) );
		
//-------------------------------------------------------------------------------------------------------------------//
// Home Section
//-------------------------------------------------------------------------------------------------------------------//
	
	$wp_customize->add_section( 'photographer_home_section' , array(
		'title'       => __( 'Home Slideshow', 'organicthemes' ),
		'priority'    => 80,
	) );

		// Slider Category Select
		$wp_customize->add_setting( 'photographer_slideshow_category' , array(
			'default' => '0',
			'sanitize_callback' => 'photographer_sanitize_categories',
		) );
		$wp_customize->add_control( new Photographer_Category_Dropdown_Control( $wp_customize, 'photographer_slideshow_category', array(
			'label'		=> __( 'Slideshow Category', 'organicthemes' ),
			'section'	=> 'photographer_home_section',
			'settings'	=> 'photographer_slideshow_category',
			'type'		=> 'dropdown-categories',
			'priority' => 10,
		) ) );

		// Slider Postnumber
		$wp_customize->add_setting( 'photographer_slideshow_postnumber' , array(
			'default' => '12',
			'sanitize_callback' => 'photographer_sanitize_text',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'photographer_slideshow_postnumber', array(
			'label'		=> __( 'Slideshow Posts Number', 'organicthemes' ),
			'section'	=> 'photographer_home_section',
			'settings'	=> 'photographer_slideshow_postnumber',
			'type'		=> 'text',
			'priority' => 20,
		) ) );
		
		// Slider Transition Interval
		$wp_customize->add_setting( 'photographer_transition_interval', array(
    		'default' => '8000',
    		'sanitize_callback' => 'photographer_sanitize_transition_interval',
    	) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'photographer_transition_interval', array(
		    'type' => 'select',
		    'label' => __( 'Transition Interval', 'organicthemes' ),
		    'section' => 'photographer_home_section',
		    'choices' => array(
		        '2000' 		=> __( '2 Seconds', 'organicthemes' ),
		        '4000' 		=> __( '4 Seconds', 'organicthemes' ),
		        '6000' 		=> __( '6 Seconds', 'organicthemes' ),
		        '8000' 		=> __( '8 Seconds', 'organicthemes' ),
		        '10000' 	=> __( '10 Seconds', 'organicthemes' ),
		        '12000' 	=> __( '12 Seconds', 'organicthemes' ),
		        '20000' 	=> __( '20 Seconds', 'organicthemes' ),
		        '30000' 	=> __( '30 Seconds', 'organicthemes' ),
		        '60000' 	=> __( '1 Minute', 'organicthemes' ),
		        '999999999'	=> __( 'Hold Frame', 'organicthemes' ),
		    ),
	    'priority' => 30,
		) ) );
		
		// Slider Transition Style
		$wp_customize->add_setting( 'photographer_transition_style', array(
    		'default' => 'fade',
      		'sanitize_callback' => 'photographer_sanitize_transition_style',
    	) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'photographer_transition_style', array(
	        'type' => 'select',
	        'label' => __( 'Transition Style', 'organicthemes' ),
	        'section' => 'photographer_home_section',
	        'choices' => array(
	            'fade' 		=> __( 'Fade', 'organicthemes' ),
	            'slide' 	=> __( 'Slide', 'organicthemes' ),
		    ),
		    'priority' => 40,
		) ) );

//-------------------------------------------------------------------------------------------------------------------//
// Portfolio Section
//-------------------------------------------------------------------------------------------------------------------//

	$wp_customize->add_section( 'portfolio_section' , array(
		'title'       => __( 'Portfolio Options', 'organicthemes' ),
		'priority'    => 85,
	) );

	   	// Portfolio Category Select
		$wp_customize->add_setting( 'portfolio_category' , array(
			'default' => '0',
			'sanitize_callback' => 'photographer_sanitize_categories',
		) );
		$wp_customize->add_control( new Photographer_Category_Dropdown_Control( $wp_customize, 'portfolio_category', array(
			'label'		=> __( 'Portfolio Template Category', 'organicthemes' ),
			'section'	=> 'portfolio_section',
			'settings'	=> 'portfolio_category',
			'type'		=> 'dropdown-categories',
			'priority' => 10,
		) ) );
	
		// Portfolio Postnumber
		$wp_customize->add_setting( 'portfolio_postnumber' , array(
			'default' => '12',
			'sanitize_callback' => 'photographer_sanitize_text',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'portfolio_postnumber', array(
			'label'		=> __( 'Portfolio Template Posts', 'organicthemes' ),
			'section'	=> 'portfolio_section',
			'settings'	=> 'portfolio_postnumber',
			'type'		=> 'text',
			'priority' => 20,
		) ) );
	
		// Portfolio Columns Option
		$wp_customize->add_setting( 'portfolio_columns', array(
	    	'default' => 'three',
	    	'sanitize_callback' => 'photographer_sanitize_columns',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'portfolio_columns', array(
	    	'label' => __( 'Portfolio Template Columns', 'organicthemes' ),
	    	'section' => 'portfolio_section',
	    	'settings' => 'portfolio_columns',
	    	'type' => 'radio',
	    	'choices' => array(
	        	'one' 		=> __( 'One Column', 'organicthemes' ),
	        	'two' 		=> __( 'Two Columns', 'organicthemes' ),
	        	'three' 	=> __( 'Three Columns', 'organicthemes' ),
	        	'four' 		=> __( 'Four Columns', 'organicthemes' ),
	    	),
	    	'priority' => 30,
			) ) );
			   		
		// Category Columns Option
		$wp_customize->add_setting( 'category_columns', array(
			'default' => 'two',
			'sanitize_callback' => 'photographer_sanitize_columns',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'category_columns', array(
			'label' => __( 'Category Portfolio Columns', 'organicthemes' ),
			'section' => 'portfolio_section',
			'settings' => 'category_columns',
			'type' => 'radio',
			'choices' => array(
		    	'one' 		=> __( 'One Column', 'organicthemes' ),
		    	'two' 		=> __( 'Two Columns', 'organicthemes' ),
		    	'three' 	=> __( 'Three Columns', 'organicthemes' ),
		    	'four' 		=> __( 'Four Columns', 'organicthemes' ),
			),
			'priority' => 40,
		) ) );
		
		// Project Columns Option
		$wp_customize->add_setting( 'project_columns', array(
			'default' => 'two',
			'sanitize_callback' => 'photographer_sanitize_columns',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'project_columns', array(
			'label' => __( 'Project Template Columns', 'organicthemes' ),
			'section' => 'portfolio_section',
			'settings' => 'project_columns',
			'type' => 'radio',
			'choices' => array(
		    	'one' 		=> __( 'One Column', 'organicthemes' ),
		    	'two' 		=> __( 'Two Columns', 'organicthemes' ),
		    	'three' 	=> __( 'Three Columns', 'organicthemes' ),
		    	'four' 		=> __( 'Four Columns', 'organicthemes' ),
			),
			'priority' => 50,
		) ) );
		
		// Display Project Slideshow
		$wp_customize->add_setting( 'display_project_slideshow', array(
			'default'	=> false,
			'sanitize_callback' => 'photographer_sanitize_checkbox',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'display_project_slideshow', array(
			'label'		=> __( 'Show Project Slideshow?', 'organicthemes' ),
			'description' => __( 'Displays a slideshow in place of featured image on Jetpack projects.', 'organicthemes' ),
			'section'	=> 'portfolio_section',
			'settings'	=> 'display_project_slideshow',
			'type'		=> 'checkbox',
			'priority' => 60,
		) ) );
		
//-------------------------------------------------------------------------------------------------------------------//
// Blog Section
//-------------------------------------------------------------------------------------------------------------------//
	
	$wp_customize->add_section( 'photographer_blog_section' , array(
		'title'       => __( 'Blog Options', 'organicthemes' ),
		'priority'    => 90,
	) );

		// Blog Category Select
		$wp_customize->add_setting( 'photographer_blog_category' , array(
			'default' => '0',
			'sanitize_callback' => 'photographer_sanitize_categories',
		) );
		$wp_customize->add_control( new Photographer_Category_Dropdown_Control( $wp_customize, 'photographer_blog_category', array(
			'label'		=> __( 'Blog Category', 'organicthemes' ),
			'section'	=> 'photographer_blog_section',
			'settings'	=> 'photographer_blog_category',
			'type'		=> 'dropdown-categories',
			'priority' => 10,
		) ) );

		// Blog Postnumber
		$wp_customize->add_setting( 'photographer_blog_postnumber' , array(
			'default' => '10',
			'sanitize_callback' => 'photographer_sanitize_text',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'photographer_blog_postnumber', array(
			'label'		=> __( 'Blog Posts Number', 'organicthemes' ),
			'section'	=> 'photographer_blog_section',
			'settings'	=> 'photographer_blog_postnumber',
			'type'		=> 'text',
			'priority' => 20,
		) ) );

//-------------------------------------------------------------------------------------------------------------------//
// Layout
//-------------------------------------------------------------------------------------------------------------------//
	
	$wp_customize->add_section( 'photographer_layout_section' , array(
		'title'       => __( 'Layout & Style', 'organicthemes' ),
		'priority'    => 95,
	) );
	
		// Footer Text
		$wp_customize->add_setting( 'footer_text', array(
			'sanitize_callback' => 'photographer_sanitize_text',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'footer_text', array(
			'label'		=> __( 'Footer Text', 'organicthemes' ),
			'section'	=> 'photographer_layout_section',
			'settings'	=> 'footer_text',
			'type'		=> 'text',
			'priority' => 10,
		) ) );

   		// Display Post Featured Image or Video
   		$wp_customize->add_setting( 'display_post_featured', array(
   			'default'	=> true,
   			'sanitize_callback' => 'photographer_sanitize_checkbox',
   		) );
   		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'display_post_featured', array(
   			'label'		=> __( 'Display Post Featured Image or Video?', 'organicthemes' ),
   			'description' => __( 'Selecting this option will display the featured image or video in an individual post.', 'organicthemes' ),
   			'section'	=> 'photographer_layout_section',
   			'settings'	=> 'display_post_featured',
   			'type'		=> 'checkbox',
   			'priority' => 20,
   		) ) );

   		// Display Blog Featured Image or Video
   		$wp_customize->add_setting( 'display_blog_featured', array(
   			'default'	=> true,
   			'sanitize_callback' => 'photographer_sanitize_checkbox',
   		) );
   		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'display_blog_featured', array(
   			'label'		=> __( 'Display Blog Featured Image?', 'organicthemes' ),
   			'description' => __( 'Selecting this option will display the featured image on the blog template.', 'organicthemes' ),
   			'section'	=> 'photographer_layout_section',
   			'settings'	=> 'display_blog_featured',
   			'type'		=> 'checkbox',
   			'priority' => 30,
   		) ) );
   		
   		// Display Text overlay
		$wp_customize->add_setting( 'text_overlay', array(
			'default'	=> true,
			'sanitize_callback' => 'photographer_sanitize_checkbox',
		) );
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'text_overlay', array(
			'label'		=> __( 'Display Text Overlay?', 'organicthemes' ),
			'description' => __( 'Selecting this option will display text titles on top of featured images.', 'organicthemes' ),
			'section'	=> 'photographer_layout_section',
			'settings'	=> 'text_overlay',
			'type'		=> 'checkbox',
			'priority' => 40,
		) ) );

   		// Display Drop Shadows
   		$wp_customize->add_setting( 'drop_shadows', array(
   			'default'	=> true,
   			'sanitize_callback' => 'photographer_sanitize_checkbox',
   		) );
   		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'drop_shadows', array(
   			'label'		=> __( 'Display Drop Shadows?', 'organicthemes' ),
   			'description' => __( 'Selecting this option will display drop shadows around content boxes.', 'organicthemes' ),
   			'section'	=> 'photographer_layout_section',
   			'settings'	=> 'drop_shadows',
   			'type'		=> 'checkbox',
   			'priority' => 50,
   		) ) );

   		// Display Full Width Background
   		$wp_customize->add_setting( 'background_stretch', array(
   			'default'	=> false,
   			'sanitize_callback' => 'photographer_sanitize_checkbox',
   		) );
   		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'background_stretch', array(
   			'label'		=> __( 'Display Full Width Background?', 'organicthemes' ),
   			'description' => __( 'Enables an applied background image to stretch to the full width of the browser. Do not use with a tiled background.', 'organicthemes' ),
   			'section'	=> 'photographer_layout_section',
   			'settings'	=> 'background_stretch',
   			'type'		=> 'checkbox',
   			'priority' => 60,
   		) ) );	    	
}
add_action('customize_register', 'photographer_theme_customizer');

/**
* Binds JavaScript handlers to make Customizer preview reload changes
* asynchronously.
*/
function photographer_customize_preview_js() {
	wp_enqueue_script( 'photographer-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ) );
}
add_action( 'customize_preview_init', 'photographer_customize_preview_js' );
